import type { APIRoute } from "astro";

interface AuthRequest {
	code: string;
	requiredRole?: "guest" | "admin";
}

export const POST: APIRoute = async ({ request }) => {
	const headers = {
		"Content-Type": "application/json",
	};

	try {
		const { code, requiredRole = "guest" } = (await request.json()) as AuthRequest;
		const secretCode = process.env.SECRET_CODE || import.meta.env.SECRET_CODE;
		const adminCode = process.env.ADMIN_CODE || import.meta.env.ADMIN_CODE;

		let role = "guest";

		if (code === adminCode) {
			role = "admin";
		} else if (code !== secretCode) {
			return new Response(
				JSON.stringify({
					success: false,
					error: "Invalid code",
				}),
				{
					status: 401,
					headers,
				}
			);
		}

		if (requiredRole === "admin" && role !== "admin") {
			return new Response(
				JSON.stringify({
					success: false,
					error: "Admin access required",
				}),
				{
					status: 403,
					headers,
				}
			);
		}

		return new Response(JSON.stringify({ success: true, role }), {
			status: 200,
			headers,
		});
	} catch (error) {
		console.error("Authentication failed:", error);
		return new Response(
			JSON.stringify({
				success: false,
				error: "Authentication failed",
			}),
			{
				status: 500,
				headers,
			}
		);
	}
};
