import type { APIRoute } from "astro";
import { getS3Data, putS3Data } from "../../../lib/s3";
import { v4 as uuidv4 } from "uuid";
import type { RegistryItem } from "../../../lib/types";

const REGISTRY_FILE_KEY = "registry.json";

// GET: List all registry items
export const GET: APIRoute = async () => {
	try {
		const registry = await getS3Data<RegistryItem[]>(REGISTRY_FILE_KEY) || [];
		return new Response(JSON.stringify(registry), {
			status: 200,
			headers: { "Content-Type": "application/json" },
		});
	} catch (error: any) {
		console.error("Error listing registry items:", error.message);
		return new Response(
			JSON.stringify({ success: false, error: "Failed to list items" }),
			{ status: 500, headers: { "Content-Type": "application/json" } }
		);
	}
};

// POST: Create a new registry item
export const POST: APIRoute = async ({ request }) => {
	try {
		const body = await request.json();
		const { name, link } = body;

		if (!name) {
			return new Response(
				JSON.stringify({ success: false, error: "Name is required" }),
				{ status: 400, headers: { "Content-Type": "application/json" } }
			);
		}

		const registry = await getS3Data<RegistryItem[]>(REGISTRY_FILE_KEY) || [];
		const newItem: RegistryItem = {
			id: uuidv4(),
			name,
			taken: false,
			link,
		};

		registry.push(newItem);
		await putS3Data(REGISTRY_FILE_KEY, registry);

		return new Response(
			JSON.stringify({ success: true, itemId: newItem.id }),
			{ status: 201, headers: { "Content-Type": "application/json" } }
		);
	} catch (error: any) {
		console.error("Error adding item to registry:", error.message);
		return new Response(
			JSON.stringify({ success: false, error: "Failed to add item" }),
			{ status: 500, headers: { "Content-Type": "application/json" } }
		);
	}
};
